==> biomaRt_2.0.0.zip: biomaRt/doc/biomaRt.R <==
###################################################
### chunk number 1: annotate
###################################################
## library("annotate")
options(width=120)


###################################################
### chunk number 2: biomaRt
###################################################
library("biomaRt")
listMarts()


###################################################
### chunk number 3: ensembl1
###################################################
ensembl=useMart("ensembl")


###################################################
### chunk number 4: listDatasets
###################################################
listDatasets(ensembl)


###################################################
### chunk number 5: ensembl2
###################################################
ensembl = useMart("ensembl",dataset="hsapiens_gene_ensembl")


###################################################
### chunk number 6: filters
###################################################
filters = listFilters(ensembl)
filters[1:5,]


###################################################
### chunk number 7: attributes
###################################################
attributes = listAttributes(ensembl)
attributes[1:5,]


###################################################
### chunk number 8: affyids
###################################################
affyids=c("202763_at","209310_s_at","207500_at")
getBM(attributes=c('affy_hg_u133_plus_2', 'entrezgene'), filters = 'affy_hg_u133_plus_2', values = affyids, mart = ensembl)


###################################################
### chunk number 9: 
###################################################
affyids=c("202763_at","209310_s_at","207500_at")
getBM(attributes=c('affy_hg_u133_plus_2', 'hgnc_symbol', 'chromosome_name','start_position','end_position', 'band'),
 filters = 'affy_hg_u133_plus_2', values = affyids, mart = ensembl)


###################################################
### chunk number 10: 
###################################################
entrez=c("673","837")
getBM(attributes=c('entrezgene','go_biological_process_id'), filters='entrezgene', values=entrez, mart=ensembl)


###################################################
### chunk number 11:  eval=FALSE
###################################################
## refseqids = c("NM_005359","NM_000546")
## ipro = getBM(attributes=c("refseq_dna","interpro","interpro_description"), filters="refseq_dna",values=refseqids, mart=ensembl)


###################################################
### chunk number 12: 
###################################################
getBM(c('affy_hg_u133_plus_2','ensembl_gene_id'), filters = c('chromosome_name','start','end'),
 values=list(16,1100000,1250000), mart=ensembl)


###################################################
### chunk number 13: 
###################################################
getBM(c('entrezgene','hgnc_symbol'), filters='go', values='GO:0004707', mart=ensembl)


###################################################
### chunk number 14:  eval=FALSE
###################################################
## entrez=c("673","7157","837")
## getSequence(id = entrez, type="entrezgene",seqType="coding_gene_flank",upstream=100, mart=ensembl) 


###################################################
### chunk number 15:  eval=FALSE
###################################################
## utr5 = getSequence(chromosome=3, start=185514033, end=185535839,
##                       type="entrezgene",seqType="5utr", mart=ensembl)
## utr5


###################################################
### chunk number 16:  eval=FALSE
###################################################
## protein = getSequence(id=c(100, 5728),type="entrezgene",
##                         seqType="peptide", mart=ensembl)
## protein


###################################################
### chunk number 17:  eval=FALSE
###################################################
## snpmart = useMart("snp", dataset="hsapiens_snp")


###################################################
### chunk number 18:  eval=FALSE
###################################################
## getBM(c('refsnp_id','allele','chrom_start','chrom_strand'), filters = c('chr_name','chrom_start','chrom_end'), values = list(8,148350,148612), mart = snpmart)


###################################################
### chunk number 19: 
###################################################
listMarts(archive=TRUE)


###################################################
### chunk number 20:  eval=FALSE
###################################################
## ensembl = useMart("ensembl_mart_46", dataset="hsapiens_gene_ensembl", archive = TRUE)


###################################################
### chunk number 21:  eval=FALSE
###################################################
## wormbase=useMart("wormbase_current",dataset="wormbase_gene")
## listFilters(wormbase)
## listAttributes(wormbase)
## getBM(attributes=c("name","rnai","rnai_phenotype","phenotype_desc"),
##                      filters="gene_name", values=c("unc-26","his-33"),
##                      mart=wormbase)
##      


###################################################
### chunk number 22: 
###################################################
filterType("with_affy_hg_u133_plus_2",ensembl)


###################################################
### chunk number 23: 
###################################################
filterOptions("biotype",ensembl)


###################################################
### chunk number 24: 
###################################################
pages = attributePages(ensembl)
pages


###################################################
### chunk number 25: 
###################################################
listAttributes(ensembl, page="feature_page")


###################################################
### chunk number 26: 
###################################################
sessionInfo()
warnings()

==> biomaRt_2.6.0.zip: biomaRt/doc/biomaRt.R <==
###################################################
### chunk number 1: annotate
###################################################
#line 35 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpbLLjQa/R.INSTALL3eda7558/biomaRt/inst/doc/biomaRt.Rnw"
## library("annotate")
options(width=120)


###################################################
### chunk number 2: biomaRt
###################################################
#line 41 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpbLLjQa/R.INSTALL3eda7558/biomaRt/inst/doc/biomaRt.Rnw"
library("biomaRt")
listMarts()


###################################################
### chunk number 3: ensembl1
###################################################
#line 56 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpbLLjQa/R.INSTALL3eda7558/biomaRt/inst/doc/biomaRt.Rnw"
ensembl=useMart("ensembl")


###################################################
### chunk number 4: listDatasets
###################################################
#line 63 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpbLLjQa/R.INSTALL3eda7558/biomaRt/inst/doc/biomaRt.Rnw"
listDatasets(ensembl)


###################################################
### chunk number 5: ensembl2
###################################################
#line 76 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpbLLjQa/R.INSTALL3eda7558/biomaRt/inst/doc/biomaRt.Rnw"
ensembl = useMart("ensembl",dataset="hsapiens_gene_ensembl")


###################################################
### chunk number 6: filters
###################################################
#line 85 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpbLLjQa/R.INSTALL3eda7558/biomaRt/inst/doc/biomaRt.Rnw"
filters = listFilters(ensembl)
filters[1:5,]


###################################################
### chunk number 7: attributes
###################################################
#line 92 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpbLLjQa/R.INSTALL3eda7558/biomaRt/inst/doc/biomaRt.Rnw"
attributes = listAttributes(ensembl)
attributes[1:5,]


###################################################
### chunk number 8: affyids
###################################################
#line 115 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpbLLjQa/R.INSTALL3eda7558/biomaRt/inst/doc/biomaRt.Rnw"
affyids=c("202763_at","209310_s_at","207500_at")
getBM(attributes=c('affy_hg_u133_plus_2', 'entrezgene'), filters = 'affy_hg_u133_plus_2', values = affyids, mart = ensembl)


###################################################
### chunk number 9: 
###################################################
#line 129 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpbLLjQa/R.INSTALL3eda7558/biomaRt/inst/doc/biomaRt.Rnw"
affyids=c("202763_at","209310_s_at","207500_at")
getBM(attributes=c('affy_hg_u133_plus_2', 'hgnc_symbol', 'chromosome_name','start_position','end_position', 'band'),
 filters = 'affy_hg_u133_plus_2', values = affyids, mart = ensembl)


###################################################
### chunk number 10: 
###################################################
#line 141 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpbLLjQa/R.INSTALL3eda7558/biomaRt/inst/doc/biomaRt.Rnw"
entrez=c("673","837")
getBM(attributes=c('entrezgene','go_biological_process_id'), filters='entrezgene', values=entrez, mart=ensembl)


###################################################
### chunk number 11:  eval=FALSE
###################################################
## #line 173 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpbLLjQa/R.INSTALL3eda7558/biomaRt/inst/doc/biomaRt.Rnw"
## refseqids = c("NM_005359","NM_000546")
## ipro = getBM(attributes=c("refseq_dna","interpro","interpro_description"), filters="refseq_dna",values=refseqids, mart=ensembl)


###################################################
### chunk number 12: 
###################################################
#line 197 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpbLLjQa/R.INSTALL3eda7558/biomaRt/inst/doc/biomaRt.Rnw"
getBM(c('affy_hg_u133_plus_2','ensembl_gene_id'), filters = c('chromosome_name','start','end'),
 values=list(16,1100000,1250000), mart=ensembl)


###################################################
### chunk number 13: 
###################################################
#line 206 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpbLLjQa/R.INSTALL3eda7558/biomaRt/inst/doc/biomaRt.Rnw"
getBM(c('entrezgene','hgnc_symbol'), filters='go', values='GO:0004707', mart=ensembl)


###################################################
### chunk number 14:  eval=FALSE
###################################################
## #line 220 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpbLLjQa/R.INSTALL3eda7558/biomaRt/inst/doc/biomaRt.Rnw"
## entrez=c("673","7157","837")
## getSequence(id = entrez, type="entrezgene",seqType="coding_gene_flank",upstream=100, mart=ensembl) 


###################################################
### chunk number 15:  eval=FALSE
###################################################
## #line 230 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpbLLjQa/R.INSTALL3eda7558/biomaRt/inst/doc/biomaRt.Rnw"
## utr5 = getSequence(chromosome=3, start=185514033, end=185535839,
##                       type="entrezgene",seqType="5utr", mart=ensembl)
## utr5


###################################################
### chunk number 16:  eval=FALSE
###################################################
## #line 250 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpbLLjQa/R.INSTALL3eda7558/biomaRt/inst/doc/biomaRt.Rnw"
## protein = getSequence(id=c(100, 5728),type="entrezgene",
##                         seqType="peptide", mart=ensembl)
## protein


###################################################
### chunk number 17:  eval=FALSE
###################################################
## #line 269 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpbLLjQa/R.INSTALL3eda7558/biomaRt/inst/doc/biomaRt.Rnw"
## snpmart = useMart("snp", dataset="hsapiens_snp")


###################################################
### chunk number 18:  eval=FALSE
###################################################
## #line 277 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpbLLjQa/R.INSTALL3eda7558/biomaRt/inst/doc/biomaRt.Rnw"
## getBM(c('refsnp_id','allele','chrom_start','chrom_strand'), filters = c('chr_name','chrom_start','chrom_end'), values = list(8,148350,148612), mart = snpmart)


###################################################
### chunk number 19: 
###################################################
#line 331 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpbLLjQa/R.INSTALL3eda7558/biomaRt/inst/doc/biomaRt.Rnw"
listMarts(archive=TRUE)


###################################################
### chunk number 20:  eval=FALSE
###################################################
## #line 337 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpbLLjQa/R.INSTALL3eda7558/biomaRt/inst/doc/biomaRt.Rnw"
## ensembl = useMart("ensembl_mart_46", dataset="hsapiens_gene_ensembl", archive = TRUE)


###################################################
### chunk number 21:  eval=FALSE
###################################################
## #line 349 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpbLLjQa/R.INSTALL3eda7558/biomaRt/inst/doc/biomaRt.Rnw"
## listMarts(host='may2009.archive.ensembl.org')
## ensembl54=useMart(host='may2009.archive.ensembl.org', biomart='ENSEMBL_MART_ENSEMBL')
## ensembl54=useMart(host='may2009.archive.ensembl.org', biomart='ENSEMBL_MART_ENSEMBL', dataset='hsapiens_gene_ensembl')


###################################################
### chunk number 22:  eval=FALSE
###################################################
## #line 361 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpbLLjQa/R.INSTALL3eda7558/biomaRt/inst/doc/biomaRt.Rnw"
## wormbase=useMart("wormbase_current",dataset="wormbase_gene")
## listFilters(wormbase)
## listAttributes(wormbase)
## getBM(attributes=c("name","rnai","rnai_phenotype","phenotype_desc"),
##                      filters="gene_name", values=c("unc-26","his-33"),
##                      mart=wormbase)
##      


###################################################
### chunk number 23: 
###################################################
#line 423 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpbLLjQa/R.INSTALL3eda7558/biomaRt/inst/doc/biomaRt.Rnw"
filterType("with_affy_hg_u133_plus_2",ensembl)


###################################################
### chunk number 24: 
###################################################
#line 433 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpbLLjQa/R.INSTALL3eda7558/biomaRt/inst/doc/biomaRt.Rnw"
filterOptions("biotype",ensembl)


###################################################
### chunk number 25: 
###################################################
#line 449 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpbLLjQa/R.INSTALL3eda7558/biomaRt/inst/doc/biomaRt.Rnw"
pages = attributePages(ensembl)
pages


###################################################
### chunk number 26: 
###################################################
#line 458 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpbLLjQa/R.INSTALL3eda7558/biomaRt/inst/doc/biomaRt.Rnw"
listAttributes(ensembl, page="feature_page")


###################################################
### chunk number 27: 
###################################################
#line 482 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpbLLjQa/R.INSTALL3eda7558/biomaRt/inst/doc/biomaRt.Rnw"
sessionInfo()
warnings()
